@@ -6,10 +6,10 @@
  *
  * tcp_vs_http_parser.c: KTCPVS HTTP parsing engine
  *
- * Version:     $Id: tcp_vs_http_parser.c,v 1.3 2003/06/14 09:04:11 wensong Exp $
+ * Version:     $Id: tcp_vs_http_parser.c,v 1.4 2003/06/14 16:09:47 wensong Exp $
  *
- * Authors:     Wensong Zhang, <wensong@linuxvirtualserver.org>
- *              Hai Long, <david_lung@yahoo.com>
+ * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
+ *              Hai Long <david_lung@yahoo.com>
  *
  *              This program is free software; you can redistribute it and/or
  *              modify it under the terms of the GNU General Public License
@@ -22,6 +22,7 @@
 #include <linux/ctype.h>
 
 #include "tcp_vs.h"
+#include "tcp_vs_http_parser.h"
 
 #define HTTP_VERSION_HEADER_LEN		5
 #define HTTP_VERSION_NUMBER_LEN		3
@@ -41,6 +42,7 @@ typedef struct http_mime_parse_s {
 
 static http_mime_parse_t http_mime_parse_table[MAX_MIME_HEADER_STRING_LEN];
 
+
 /****************************************************************************
 *	skip whitespace
 *       LWS            = [CRLF] 1*( SP | HT )
@@ -55,6 +57,7 @@ skip_lws(const char *buffer)
 	return s;
 }
 
+
 /****************************************************************************
 *	search the seperator in a string
 */
@@ -77,6 +80,7 @@ search_sep(const char *s, int len, const char *sep)
 	return NULL;
 }
 
+
 /****************************************************************************
 *	extract the attribute-value pair
 *	The input string has the form: A = "V", and it will also accept
@@ -197,6 +201,7 @@ extract_av(char **buffer, char **attribute, char **value)
 	return ret;
 }
 
+
 /****************************************************************************
 *	This doesn't accept 0x if the radix is 16. The overflow code assumes
 *	a 2's complement architecture
@@ -1188,4 +1193,3 @@ http_mime_parse(char *buffer, int len, http_mime_header_t * mime)
 	buffer[len] = c;	/* restore string */
 	return ret;
 }
-
