@@ -1,7 +1,7 @@
 /*
  *      tcpvsadm - TCP Virtual Server ADMinistration program
  *
- *      Version: $Id: tcpvsadm.c,v 1.11 2003/02/27 02:54:40 wensong Exp $
+ *      Version: $Id: tcpvsadm.c,v 1.12 2003/05/23 02:08:34 wensong Exp $
  *
  *      Authors: Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -23,7 +23,7 @@
  *
  */
 
-#undef __KERNEL__       /* Makefile lazyness ;) */
+#undef __KERNEL__		/* Makefile lazyness ;) */
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
@@ -88,7 +88,7 @@ static int modprobe_ktcpvs(void);
 #define CMD_LOADCF		0x1000U
 #define NUMBER_OF_CMD		13
 
-static const char* cmdnames[] = {
+static const char *cmdnames[] = {
 	"add-service",
 	"edit-service",
 	"delele-service",
@@ -115,7 +115,7 @@ static const char* cmdnames[] = {
 #define OPT_PATTERN	0x00080
 #define NUMBER_OF_OPT	9
 
-static const char* optnames[] = {
+static const char *optnames[] = {
 	"numeric",
 	"ident",
 	"scheduler",
@@ -134,9 +134,8 @@ static const char* optnames[] = {
  *  '1'  exclusive (only one '1' option can be supplied)
  *  ' '  optional
  */
-static const char commands_v_options[NUMBER_OF_CMD][NUMBER_OF_OPT] =
-{
-	/*     -n   -i   -s   ads  prt  -r   -w   -p */
+static const char commands_v_options[NUMBER_OF_CMD][NUMBER_OF_OPT] = {
+/*             -n   -i   -s   ads  prt  -r   -w   -p */
 /*ADD*/       {'x', '+', ' ', ' ', ' ', 'x', 'x', 'x'},
 /*EDIT*/      {'x', '+', ' ', ' ', ' ', 'x', 'x', 'x'},
 /*DEL*/       {'x', '+', 'x', 'x', 'x', 'x', 'x', 'x'},
@@ -152,8 +151,7 @@ static const char commands_v_options[NUMBER_OF_CMD][NUMBER_OF_OPT] =
 /*LOAD-CF*/   {'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x'},
 };
 
-static struct option long_options[] =
-{
+static struct option long_options[] = {
 	{"add-service", 0, 0, 'A'},
 	{"edit-service", 0, 0, 'E'},
 	{"delete-service", 0, 0, 'D'},
@@ -179,28 +177,29 @@ static struct option long_options[] =
 };
 
 
-int main(int argc, char **argv)
+int
+main(int argc, char **argv)
 {
 	const char *optstring = "AEDFaedLlf:hi:s:P:r:p:n";
 	int c, parse;
 	char cf[128];
 	unsigned int command = CMD_NONE;
 	unsigned int options = OPT_NONE;
-	unsigned int format  = FMT_NONE;
+	unsigned int format = FMT_NONE;
 	struct tcp_vs_ident ident;
-	struct tcp_vs_config  conf;
+	struct tcp_vs_config conf;
 	struct tcp_vs_dest_u dest;
 	struct tcp_vs_rule_u rule;
 	int result = 0;
 
-	if(tcpvs_init()) {
+	if (tcpvs_init()) {
 		/* try to insmod the ip_vs module if ipvs_init failed */
 		if (modprobe_ktcpvs() || tcpvs_init())
 			fail(2, "%s", tcpvs_strerror(errno));
 	}
 
 	/* If no other arguement, list the ktcpvs service table */
-	if (argc == 1){
+	if (argc == 1) {
 		list_all(format);
 		tcpvs_close();
 		return 0;
@@ -213,16 +212,16 @@ int main(int argc, char **argv)
 	memset(&rule, 0, sizeof(rule));
 
 	/* default values */
-	conf.port		= htons(8080);
-	conf.maxSpareServers	= 18;
-	conf.minSpareServers	= 6;
-	conf.startservers	= 8;
-	conf.maxClients		= 256;
-	dest.weight		= 1;
+	conf.port = htons(8080);
+	conf.maxSpareServers = 18;
+	conf.minSpareServers = 6;
+	conf.startservers = 8;
+	conf.maxClients = 256;
+	dest.weight = 1;
 	strcpy(conf.sched_name, DEFAULT_SCHEDULER);
 
 	/*
-	 *	Parse options
+	 *      Parse options
 	 */
 	if ((c = getopt_long(argc, argv, optstring,
 			     long_options, NULL)) == EOF)
@@ -277,12 +276,13 @@ int main(int argc, char **argv)
 		tryhelp_exit(-1);
 	}
 
-	while ((c=getopt_long(argc, argv, optstring,
-			      long_options, NULL)) != EOF) {
+	while ((c = getopt_long(argc, argv, optstring,
+				long_options, NULL)) != EOF) {
 		switch (c) {
 		case 'i':
 			set_option(&options, OPT_IDENT);
-			strncpy(ident.name, optarg, KTCPVS_IDENTNAME_MAXLEN);
+			strncpy(ident.name, optarg,
+				KTCPVS_IDENTNAME_MAXLEN);
 			break;
 		case 's':
 			set_option(&options, OPT_SCHEDULER);
@@ -311,7 +311,8 @@ int main(int argc, char **argv)
 			break;
 		case 'p':
 			set_option(&options, OPT_PATTERN);
-			strncpy(rule.pattern, optarg, KTCPVS_PATTERN_MAXLEN);
+			strncpy(rule.pattern, optarg,
+				KTCPVS_PATTERN_MAXLEN);
 			rule.len = strlen(optarg);
 			break;
 		case 'n':
@@ -385,9 +386,11 @@ int main(int argc, char **argv)
 }
 
 
-static int modprobe_ktcpvs(void)
+static int
+modprobe_ktcpvs(void)
 {
-	char *argv[] = { "/sbin/modprobe", "-s", "-k", "--", "ktcpvs", NULL };
+	char *argv[] =
+	    { "/sbin/modprobe", "-s", "-k", "--", "ktcpvs", NULL };
 	int child;
 	int status;
 	int rc;
@@ -407,7 +410,8 @@ static int modprobe_ktcpvs(void)
 }
 
 
-static int load_configfile(char *cf)
+static int
+load_configfile(char *cf)
 {
 	struct tcpvs_config config;
 	struct tcpvs_service *svc;
@@ -485,31 +489,34 @@ print_service(struct tcp_vs_service_u *svc, unsigned int format)
 					   ntohs(svc->conf.redirect_port),
 					   IPPROTO_TCP, format);
 		if (!name)
-			fail(2, "addrport_to_anyname: %s", strerror(errno));
+			fail(2, "addrport_to_anyname: %s",
+			     strerror(errno));
 		printf("    redirect = %s\n", name);
 		free(name);
 	}
 
 	/* print all the destination entries */
-	for (i=0; i<d->num_dests; i++) {
+	for (i = 0; i < d->num_dests; i++) {
 		struct tcp_vs_dest_u *e = &d->entrytable[i];
 
 		daddr.s_addr = e->addr;
 		if (!(dname = addrport_to_anyname(&daddr, ntohs(e->port),
 						  IPPROTO_TCP, format)))
-			fail(2, "addrport_to_anyname: %s", strerror(errno));
+			fail(2, "addrport_to_anyname: %s",
+			     strerror(errno));
 		printf("    server = %s %d\n", dname, e->weight);
 		free(dname);
 	}
 
 	/* print all the rule entries */
-	for (i=0; i<r->num_rules; i++) {
+	for (i = 0; i < r->num_rules; i++) {
 		struct tcp_vs_rule_u *e = &r->entrytable[i];
 
 		daddr.s_addr = e->addr;
 		if (!(dname = addrport_to_anyname(&daddr, ntohs(e->port),
 						  IPPROTO_TCP, format)))
-			fail(2, "addrport_to_anyname: %s", strerror(errno));
+			fail(2, "addrport_to_anyname: %s",
+			     strerror(errno));
 		printf("    rule = pattern \"%s\" use server %s\n",
 		       e->pattern, dname);
 		free(dname);
@@ -521,7 +528,8 @@ print_service(struct tcp_vs_service_u *svc, unsigned int format)
 }
 
 
-static int list_service(struct tcp_vs_ident *id, unsigned int format)
+static int
+list_service(struct tcp_vs_ident *id, unsigned int format)
 {
 	struct tcp_vs_service_u *svc;
 
@@ -534,7 +542,8 @@ static int list_service(struct tcp_vs_ident *id, unsigned int format)
 }
 
 
-static int list_all(unsigned int format)
+static int
+list_all(unsigned int format)
 {
 	struct tcp_vs_get_services *get;
 	int i;
@@ -545,7 +554,7 @@ static int list_all(unsigned int format)
 	if (!(get = tcpvs_get_services()))
 		return -1;
 
-	for (i=0; i<get->num_services; i++)
+	for (i = 0; i < get->num_services; i++)
 		print_service(&get->entrytable[i], format);
 	free(get);
 	return 0;
@@ -560,12 +569,12 @@ generic_opt_check(int command, int options)
 
 	/* Check that commands are valid with options. */
 	for (i = 0; i < NUMBER_OF_CMD; i++) {
-		if (command & (1<<i))
+		if (command & (1 << i))
 			break;
 	}
 
 	for (j = 0; j < NUMBER_OF_OPT; j++) {
-		if (!(options & (1<<j))) {
+		if (!(options & (1 << j))) {
 			if (commands_v_options[i][j] == '+')
 				fail(2, "You need to supply the '%s' "
 				     "option for the '%s' command",
@@ -581,9 +590,11 @@ generic_opt_check(int command, int options)
 					last = j;
 					continue;
 				}
-				fail(2, "The option '%s' conflicts with the "
+				fail(2,
+				     "The option '%s' conflicts with the "
 				     "'%s' option in the '%s' command",
-				     optnames[j], optnames[last], cmdnames[i]);
+				     optnames[j], optnames[last],
+				     cmdnames[i]);
 			}
 		}
 	}
@@ -610,20 +621,24 @@ static void
 set_option(unsigned int *options, unsigned int option)
 {
 	if (*options & option)
-		fail(2, "multiple '%s' options specified", opt2name(option));
+		fail(2, "multiple '%s' options specified",
+		     opt2name(option));
 	*options |= option;
 }
 
 
-static void tryhelp_exit(const int status)
+static void
+tryhelp_exit(const int status)
 {
-	fprintf(stderr, "Try `%s -h' or '%s --help' for more information.\n",
+	fprintf(stderr,
+		"Try `%s -h' or '%s --help' for more information.\n",
 		program, program);
 	exit(status);
 }
 
 
-static void usage_exit(const int status)
+static void
+usage_exit(const int status)
 {
 	FILE *stream;
 
@@ -646,8 +661,9 @@ static void usage_exit(const int status)
 		"  %s -f config-file\n"
 		"  %s --start|stop [-i ident]\n"
 		"  %s -h\n\n",
-		program, program_version, program, program, program, program,
-		program, program, program, program, program, program, program);
+		program, program_version, program, program, program,
+		program, program, program, program, program, program,
+		program, program);
 
 	fprintf(stream,
 		"Commands:\n"
@@ -665,8 +681,7 @@ static void usage_exit(const int status)
 		"  --load-configfile -f        load a config file\n"
 		"  --start                     start the virtual services\n"
 		"  --stop                      stop the virtual services\n"
-		"  --help            -h        display this help message\n\n"
-		);
+		"  --help            -h        display this help message\n\n");
 
 	fprintf(stream,
 		"Options:\n"
@@ -683,7 +698,8 @@ static void usage_exit(const int status)
 }
 
 
-static void fail(int err, char *msg, ...)
+static void
+fail(int err, char *msg, ...)
 {
 	va_list args;
 
